==> deepin-screensaver_5.0.20.tar.xz: BUILD/customscreensaver/deepin-custom-screensaver/translations/deepin-custom-screensaver_hi_IN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hi_IN" sourcelanguage="en">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/slideshowconfigdialog.cpp" line="142"/>
        <source>Restore Defaults</source>
        <translation>141418 141511161410 10131811 14151510101114 19161910</translation>
    </message>
</context>
<context>
    <name>SelectPathWidget</name>
    <message>
        <location filename="../src/config/selectpathwidget.cpp" line="39"/>
        <source>Picture path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config/selectpathwidget.cpp" line="46"/>
        <source>Select a path of pictures</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SlideShowConfigDialog</name>
    <message>
        <location filename="../src/slideshowconfigdialog.cpp" line="82"/>
        <source>Custom Screensaver</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/slideshowconfigdialog.cpp" line="129"/>
        <source>Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/slideshowconfigdialog.cpp" line="134"/>
        <source>Shuffle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/slideshowconfigdialog.cpp" line="135"/>
        <source>Slideshow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/slideshowconfigdialog.cpp" line="225"/>
        <source>Picture path</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SlideshowScreenSaver</name>
    <message>
        <location filename="../src/slideshowscreensaver.cpp" line="143"/>
        <source>Picture not found</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TimeIntervalWidget</name>
    <message>
        <location filename="../src/config/timeintervalwidget.cpp" line="44"/>
        <source>Time interval (s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config/timeintervalwidget.cpp" line="46"/>
        <source>Range</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> deepin-screensaver_6.5.2.tar.xz: BUILD/customscreensaver/deepin-custom-screensaver/translations/deepin-custom-screensaver_hi_IN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hi_IN" sourcelanguage="en">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/slideshowconfigdialog.cpp" line="142"/>
        <source>Restore Defaults</source>
        <translation>डिफ़ॉल्ट सेटिंग्स पुनर्स्थापित करें</translation>
    </message>
</context>
<context>
    <name>SelectPathWidget</name>
    <message>
        <location filename="../src/config/selectpathwidget.cpp" line="39"/>
        <source>Picture path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config/selectpathwidget.cpp" line="46"/>
        <source>Select a path of pictures</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SlideShowConfigDialog</name>
    <message>
        <location filename="../src/slideshowconfigdialog.cpp" line="82"/>
        <source>Custom Screensaver</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/slideshowconfigdialog.cpp" line="129"/>
        <source>Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/slideshowconfigdialog.cpp" line="134"/>
        <source>Shuffle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/slideshowconfigdialog.cpp" line="135"/>
        <source>Slideshow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/slideshowconfigdialog.cpp" line="225"/>
        <source>Picture path</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SlideshowScreenSaver</name>
    <message>
        <location filename="../src/slideshowscreensaver.cpp" line="143"/>
        <source>Picture not found</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TimeIntervalWidget</name>
    <message>
        <location filename="../src/config/timeintervalwidget.cpp" line="44"/>
        <source>Time interval (s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config/timeintervalwidget.cpp" line="46"/>
        <source>Range</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
